color_deficiency_widget library
Classes
- ColorDeficiencyDropdown
- A widget that provides a DropdownButton with different Color Vision Deficiency (CVD) types. Upon selection, the selected CVD will be applied by ColorDeficiencyFiltered
- ColorDeficiencyFiltered
- Filters the color of child to approximate the selected ColorDeficiencyFilter. Use this towards the top of your widget tree, for example above your MaterialApp.
Properties
-
currentColorDeficiencyFilterNotifier
↔ ValueNotifier<
ColorDeficiencyFilter?> -
getter/setter pair